==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/core/classes/DAL/QueryFactory.php <==
<?php
namespace Claromentis\Core\DAL;

$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"] ?: array()) + array();
class QueryFactory
{
    
    
    
    
    
    
    
    
    
    public function GetQueryInsert(string $_c81a475ecdc9121925813756400e25f9, array $_83fa8012bfbdb8012d69e93e13d01503 = []) : QueryInsert
    {
        return new QueryInsert($_c81a475ecdc9121925813756400e25f9, $_83fa8012bfbdb8012d69e93e13d01503);
    }
    
    
    
    
    
    
    
    
    
    
    public function GetQueryUpdate(string $_c81a475ecdc9121925813756400e25f9, string $_a5a8b9d897aa719dd04368fc1d38aeda, array $_f826a8b91bdcebbdac5b91c45f71fb10 = []) : QueryUpdate
    {
        return new QueryUpdate($_c81a475ecdc9121925813756400e25f9, $_a5a8b9d897aa719dd04368fc1d38aeda, $_f826a8b91bdcebbdac5b91c45f71fb10);
    }
    
    
    
    
    
    
    
    
    public function GetQueryBuilder(string $_375b33ec4eb58c7d0a9e2fc367c30c68) : QueryBuilder
    {
        return new QueryBuilder($_375b33ec4eb58c7d0a9e2fc367c30c68);
    }
    
    
    
    
    
    
    
    
    
    public function GetQuery(string $_375b33ec4eb58c7d0a9e2fc367c30c68, ...$_4c4d12d3e4f6cac68e3eecffe9887915) : Query
    {
        return new Query($_375b33ec4eb58c7d0a9e2fc367c30c68, ...$_4c4d12d3e4f6cac68e3eecffe9887915);
    }
    
    
    
    
    
    
    
    
    
    public function GetQueryPart(string $_375b33ec4eb58c7d0a9e2fc367c30c68, ...$_4c4d12d3e4f6cac68e3eecffe9887915) : QueryPart
    {
        return new QueryPart($_375b33ec4eb58c7d0a9e2fc367c30c68, ...$_4c4d12d3e4f6cac68e3eecffe9887915);
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/core/classes/DAL/QueryFactory.php <==
<?php
namespace Claromentis\Core\DAL;

$GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"] = (@$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] ?: array()) + array();
class QueryFactory
{
    
    
    
    
    
    
    
    
    
    public function GetQueryInsert(string $_c81a475ecdc9121925813756400e25f9, array $_83fa8012bfbdb8012d69e93e13d01503 = []) : QueryInsert
    {
        return new QueryInsert($_c81a475ecdc9121925813756400e25f9, $_83fa8012bfbdb8012d69e93e13d01503);
    }
    
    
    
    
    
    
    
    
    
    
    public function GetQueryUpdate(string $_c81a475ecdc9121925813756400e25f9, string $_a5a8b9d897aa719dd04368fc1d38aeda, array $_f826a8b91bdcebbdac5b91c45f71fb10 = []) : QueryUpdate
    {
        return new QueryUpdate($_c81a475ecdc9121925813756400e25f9, $_a5a8b9d897aa719dd04368fc1d38aeda, $_f826a8b91bdcebbdac5b91c45f71fb10);
    }
    
    
    
    
    
    
    
    
    public function GetQueryBuilder(string $_375b33ec4eb58c7d0a9e2fc367c30c68) : QueryBuilder
    {
        return new QueryBuilder($_375b33ec4eb58c7d0a9e2fc367c30c68);
    }
    
    
    
    
    
    
    
    
    
    public function GetQuery(string $_375b33ec4eb58c7d0a9e2fc367c30c68, ...$_4c4d12d3e4f6cac68e3eecffe9887915) : Query
    {
        return new Query($_375b33ec4eb58c7d0a9e2fc367c30c68, ...$_4c4d12d3e4f6cac68e3eecffe9887915);
    }
    
    
    
    
    
    
    
    
    
    public function GetQueryPart(string $_375b33ec4eb58c7d0a9e2fc367c30c68, ...$_4c4d12d3e4f6cac68e3eecffe9887915) : QueryPart
    {
        return new QueryPart($_375b33ec4eb58c7d0a9e2fc367c30c68, ...$_4c4d12d3e4f6cac68e3eecffe9887915);
    }
}
